package com.bonus.canteen.menu.service.impl;

import java.util.List;
import com.bonus.common.core.exception.ServiceException;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.canteen.menu.mapper.MenuNutritionMapper;
import com.bonus.canteen.menu.domain.MenuNutrition;
import com.bonus.canteen.menu.service.IMenuNutritionService;

/**
 * 食材营养基础信息Service业务层处理
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Service
public class MenuNutritionServiceImpl implements IMenuNutritionService {
    @Autowired
    private MenuNutritionMapper menuNutritionMapper;

    /**
     * 查询食材营养基础信息
     * 
     * @param id 食材营养基础信息主键
     * @return 食材营养基础信息
     */
    @Override
    public MenuNutrition selectMenuNutritionById(Long id) {
        return menuNutritionMapper.selectMenuNutritionById(id);
    }

    /**
     * 查询食材营养基础信息列表
     * 
     * @param menuNutrition 食材营养基础信息
     * @return 食材营养基础信息
     */
    @Override
    public List<MenuNutrition> selectMenuNutritionList(MenuNutrition menuNutrition) {
        return menuNutritionMapper.selectMenuNutritionList(menuNutrition);
    }

    /**
     * 新增食材营养基础信息
     * 
     * @param menuNutrition 食材营养基础信息
     * @return 结果
     */
    @Override
    public int insertMenuNutrition(MenuNutrition menuNutrition) {
        menuNutrition.setCreateTime(DateUtils.getNowDate());
        try {
            return menuNutritionMapper.insertMenuNutrition(menuNutrition);
        } catch (Exception e) {
            throw new ServiceException("错误信息描述");
        }
    }

    /**
     * 修改食材营养基础信息
     * 
     * @param menuNutrition 食材营养基础信息
     * @return 结果
     */
    @Override
    public int updateMenuNutrition(MenuNutrition menuNutrition) {
        menuNutrition.setUpdateTime(DateUtils.getNowDate());
        try {
            return menuNutritionMapper.updateMenuNutrition(menuNutrition);
        } catch (Exception e) {
            throw new ServiceException("错误信息描述");
        }
    }

    /**
     * 批量删除食材营养基础信息
     * 
     * @param ids 需要删除的食材营养基础信息主键
     * @return 结果
     */
    @Override
    public int deleteMenuNutritionByIds(Long[] ids) {
        return menuNutritionMapper.deleteMenuNutritionByIds(ids);
    }

    /**
     * 删除食材营养基础信息信息
     * 
     * @param id 食材营养基础信息主键
     * @return 结果
     */
    @Override
    public int deleteMenuNutritionById(Long id) {
        return menuNutritionMapper.deleteMenuNutritionById(id);
    }
}
