package com.bonus.canteen.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.menu.domain.MenuNutrition;
import com.bonus.canteen.menu.service.IMenuNutritionService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 食材营养基础信息Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "食材营养基础信息接口")
@RestController
@RequestMapping("/menu_nutrition")
public class MenuNutritionController extends BaseController {
    @Autowired
    private IMenuNutritionService menuNutritionService;

    /**
     * 查询食材营养基础信息列表
     */
    @ApiOperation(value = "查询食材营养基础信息列表")
    //@RequiresPermissions("menu:nutrition:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuNutrition menuNutrition) {
        startPage();
        List<MenuNutrition> list = menuNutritionService.selectMenuNutritionList(menuNutrition);
        return getDataTable(list);
    }

    /**
     * 导出食材营养基础信息列表
     */
    @ApiOperation(value = "导出食材营养基础信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:export")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出食材营养基础信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuNutrition menuNutrition) {
        List<MenuNutrition> list = menuNutritionService.selectMenuNutritionList(menuNutrition);
        ExcelUtil<MenuNutrition> util = new ExcelUtil<MenuNutrition>(MenuNutrition.class);
        util.exportExcel(response, list, "食材营养基础信息数据");
    }

    /**
     * 获取食材营养基础信息详细信息
     */
    @ApiOperation(value = "获取食材营养基础信息详细信息")
    //@RequiresPermissions("menu:nutrition:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuNutritionService.selectMenuNutritionById(id));
    }

    /**
     * 新增食材营养基础信息
     */
    @ApiOperation(value = "新增食材营养基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:add")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增食材营养基础信息")
    @PostMapping
    public AjaxResult add(@RequestBody MenuNutrition menuNutrition) {
        try {
            return toAjax(menuNutritionService.insertMenuNutrition(menuNutrition));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改食材营养基础信息
     */
    @ApiOperation(value = "修改食材营养基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:edit")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改食材营养基础信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuNutrition menuNutrition) {
        try {
            return toAjax(menuNutritionService.updateMenuNutrition(menuNutrition));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除食材营养基础信息
     */
    @ApiOperation(value = "删除食材营养基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:nutrition:remove")
    @SysLog(title = "食材营养基础信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除食材营养基础信息")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuNutritionService.deleteMenuNutritionByIds(ids));
    }
}
